clc
clear all

global r q c mu s delta theta gamma z
inputs=[];
options=optimset('Display','off','MaxFunEvals',200,'MaxIter',500,'Algorithm','levenberg-marquardt','TolFun',.000000001,'TolX',.000000001);

load Data  %  contains time series for theta and the survival function s

%  Calibration inputs

thetaC=0.397;  %  vacancy/unemployment value
rC=0.10/12;
z=0.41;  %  flow value while unemployed
%  s is loaded above

% Starting values for calibration calculation

mu=0.8759;
phi=mu*thetaC^0.5;
c=1.5;
T=numel(s);
R=(1/(1+rC)).^(1:T);  %  Discounter
P=R*s;  %  PDV of unit productivity flow
q=mu*thetaC^(-0.5);  %  probability of filling vacancy
W=P-c/q;  %  wage value
J=P-W;  %  job value
U=(rC+.03)*(2*W-P)/rC; %  unemployment value
etabar=R(1:T-1)*(s(1:T-1)-s(2:T));
V=etabar*U;  %  PDV post-separation

%  Do the calculation

r=rC;
theta=thetaC;
unks=[mu;phi;c;P;J;W;U;V];
Check=Calibrate(unks);
unknew=fsolve(@Calibrate,unks,options);
CheckS=Calibrate(unknew);
mu=unknew(1);
phi=unknew(2);
c=unknew(3);
PC=unknew(4);
JC=unknew(5);
WC=unknew(6);
UC=unknew(7);
VC=unknew(8);
Calibration=unknew;
delta=1;
gamma=0;
Check2=RetVolFunc2(WC);  %  needs mu s delta theta gamma z r 
Check3=RetVolFunc(rC); 

%  Solve for rs given thetas

Results=[];
discs=[];
returns=[];
deltas=0:0.01:0.12;
row=0;

for delta=deltas  %  parameter that controls response to market conditions (prob of interruption of bargaining)
    row=row+1;
    theta=thetaC;
    r=rC;
    if delta==1
        gamma=0;  %  undefined for Nash
    else
        gamma=(((r+delta)/(1+r))*(2*WC-PC+VC)-delta*UC)/(1-delta) - z; %  value of gamma that generates the calibrated u for psi and delta
        inputs=[inputs;[r,delta,WC,PC,VC,UC,z]];
    end
    gammas(row,1)=gamma;
    unkStart=rC;
    Check(row,1)=RetVolFunc(unkStart);
    
    for t=1:numel(thetas);
        theta=thetas(t);
        unkNew=fsolve(@RetVolFunc,unkStart,options);
        rs(t,1)=12*unkNew(1);
        d=RetVolFunc(unkNew);
        discs=[discs,d];
        errs(t,1)=abs(d);
    end
    stdev=std(rs);
    Results=[Results;[delta,stdev,max(errs)]];
    returns=[returns,[delta;100*rs]];
    Vars=[real(rs),thetas,real(errs)];
    if max(errs)<10^(-10)
        sigmas(row,1)=stdev;
    else
        sigmas(row,1)=-1;
    end
end  %  delta

results=[deltas',sigmas];

%  Calculations for figures

rShock=0.2/12;
deltas=[1,0.05];
thetas=0.01:0.03:0.53; %  points on horizontal axis
fResults=[];
% thetas=thetaC;
for i=1:numel(deltas)
    delta=deltas(i); %  parameter that controls response to market conditions (prob of interruption of bargaining)
    theta=thetaC;
    r=rC;
    inputs=[inputs;[r,delta,WC,PC,VC,UC,z]];
    if delta==1
        gamma=0;  %  undefined for Nash
    else
        gamma=(((r+delta)/(1+r))*(2*WC-PC+VC)-delta*UC)/(1-delta) - z;  %  value of gamma that generates the calibrated u for psi and delta
    end
    Check_base(i,1)=RetVolFunc2(WC);  %  verify that the model solves at this calibration
    unkStart=WC;

    for theta=thetas;  %  build a row of Results for each theta; the row has J and W values for 2 sets of driving values 
        q=mu*theta^(-0.5);
        
        %  Base case
        
        r=rC;
        T=numel(s);
        R=(1/(1+r)).^(1:T);  %  Discounter
        P=R*s;  %  PDV of unit productivity flow
        unkStart=W;
        unkNew=fsolve(@RetVolFunc2,unkStart,options);
        d=RetVolFunc2(unkNew);
        ResultsRow(1,1)=P-unkNew;  %  Point on wage curve for this case
        ResultsRow(1,2)=c/q;  %  Point on the job-value curve for this case
        ResultsRow(1,3)=d; %  Accuracy
               
        %  Higher discount
        
        r=rShock;
        T=numel(s);
        R=(1/(1+r)).^(1:T);  %  Discounter
        P=R*s;  %  PDV of unit productivity flow
        unkStart=W;
        unkNew=fsolve(@RetVolFunc2,unkStart,options);
        d=RetVolFunc2(unkNew);
        ResultsRow(1,4)=P-unkNew;  %  Point on wage curve for this case
        ResultsRow(1,5)=c/q;  %  Point on the job-value curve for this case
        ResultsRow(1,6)=d; %  Accuracy
        
        ResultsRow(1,7)=theta;
        ResultsRow(1,8)=delta;
        
        fResults=[fResults;ResultsRow];
        
    end % thetas loop
end % deltas loop





