%  Calculates the graphs illustrating the Hall-Milg model

clc
clear all
FileName='HDHU results.xlsx';
eqTab='eq calcs';
global c mu s alpha delta theta x q gamma z r P
options=optimset('Display','off','MaxFunEvals',200,'MaxIter',500,'Algorithm','levenberg-marquardt','TolFun',.000000001,'TolX',.000000001);

%  Calibration

DpW=30;
c=0.43;
x=1;
xShock=0.99;
mu=DpW*0.8759/30;
s=DpW*0.033/30;
rC=DpW*0.10/360;
r=rC;
rShock=3*rC;
thetaC=0.374;  %  vacancy/unemployment value
theta=thetaC;
phi=mu*theta^0.5;
P=x*(1+r)/(r+s);  %  productivity value
q=mu*theta^(-.5);  %  probability of filling vacancy
W=P-c/q;  %  wage value
U=(r+s)*(2*W-P)/r;  %  unemployment value (substitute V=s*U/(r+s) into wage eq with delta=1)
V=s*U/(r+s);  %  post separation career value
z=U-(phi*(W+V)+(1-phi)*U)/(1+r);  %  flow value while unemployed
%  gamma calibrated below for delta<1

%  Check for solution at calibration

 delta=0.5;
 alpha=0.5;
 gamma=(((r+delta)/(1+r))*(2*W-P+V)-delta*U)*x/(1-delta) - z;  %  value of gamma that generates the calibrated u for delta <1
 Check=RetVolFunc2(W);
  
%  Solve for Ws given thetas

Results=[];
deltas=[1,0.1,0.1];
alphas=[1,1,0];
thetas=0.01:0.03:0.43; %  points on horizontal axis
% thetas=thetaC;
for i=1:numel(deltas)
    delta=deltas(i); %  parameter that controls response to market conditions (prob of interruption of bargaining)
    alpha=alphas(i); % parameter that controls response of z to productivity
    alpha_delta=[alpha,delta];
    theta=thetaC;
    x=1;
    r=rC;
    P=x*(1+r)/(r+s); 
    if delta==1
        gamma=0;  %  undefined for Nash
    else
        gamma=(((r+delta)/(1+r))*(2*W-P+V)-delta*U)*x/(1-delta) - z;  %  value of gamma that generates the calibrated u for delta <1
    end
    Check_base(i,1)=RetVolFunc2(W);  %  verify that the model solves at this calibration
    unkStart=W;

    for theta=thetas;  %  build a row of Results for each theta; the row has J and W values for 3 sets of driving values 
        q=mu*theta^(-0.5);
        
        %  Base case
        
        r=rC;
        x=1;
        unkStart=W;
        unkNew=fsolve(@RetVolFunc2,unkStart,options);
        d=RetVolFunc2(unkNew);
        ResultsRow(1,1)=P-unkNew;  %  Point on wage curve for this case
        ResultsRow(1,2)=c/q;  %  Point on the job-value curve for this case
        ResultsRow(1,3)=d; %  Accuracy
        
        %  Lower productivity
        
        x=xShock;
        unkStart=W;
        unkNew=fsolve(@RetVolFunc2,unkStart,options);
        d=RetVolFunc2(unkNew);
        ResultsRow(1,4)=P-unkNew;  %  Point on wage curve for this case
        ResultsRow(1,5)=c/q;  %  Point on the job-value curve for this case
        ResultsRow(1,6)=d; %  Accuracy
        
        %  Higher discount
        
        x=1;
        r=rShock;
        unkStart=W;
        unkNew=fsolve(@RetVolFunc2,unkStart,options);
        d=RetVolFunc2(unkNew);
        ResultsRow(1,7)=P-unkNew;  %  Point on wage curve for this case
        ResultsRow(1,8)=c/q;  %  Point on the job-value curve for this case
        ResultsRow(1,9)=d; %  Accuracy
        
        ResultsRow(1,10)=theta;
        ResultsRow(1,11)=delta;
        ResultsRow(1,12)=alpha;
        
        Results=[Results;ResultsRow];
        
    end % thetas loop
    
end % loop over parameter values



